---
name: OpenSTEF 4.0 Project Story
about: Describe this issue template's purpose here.
title: "[OpenSTEF 4.0] ..."
labels: OpenSTEF 4.0
assignees: ''

---

As
I want to 
So that I

❗Priority (What if we don't do this?/Are there any deadlines? etc.)

Definition of Done:

✅ Acceptance criteria

- [ ] 

📄 Documentation criteria:

Interfaces with other products and services

Update relevant confluence pages

🧪 Test criteria:

Unit tests written and passed

⌛ Dependencies:

N/A

🚀 Releasing:

N/A

Other information:

🌍 Background
